@@ -3,7 +3,7 @@ use warnings;
 package Email::MIME::Header;
 use base 'Email::Simple::Header';
 
-our $VERSION = '1.862';
+our $VERSION = '1.900';
 
 use Encode 1.9801;
 
@@ -26,6 +26,15 @@ changes:
 
 =back
 
+Note that C<header_set> does not do encoding for you, and expects an
+encoded header.  Thus, C<header_set> round-trips with C<header_raw>,
+not C<header>!  Be sure to properly encode your headers with
+C<Encode::encode('MIME-Header', $value)> before passing them to
+C<header_set>.
+
+Alternately, if you have Unicode (character) strings to set in headers, use the
+C<header_str_set> method.
+
 =cut
 
 sub header {
@@ -45,6 +54,14 @@ sub header_raw {
   return $self->SUPER::header($header);
 }
 
+sub header_str_set {
+  my ($self, $name, @vals) = @_;
+
+  my @values = map { Encode::encode('MIME-Q', $_, 1) } @vals;
+
+  $self->header_set($name => @values);
+}
+
 sub _header_decode_str {
   my ($self, $str) = @_;
   my $new_str;
@@ -53,4 +70,13 @@ sub _header_decode_str {
   return $new_str;
 }
 
+=head1 COPYRIGHT
+
+This software is copyright (c) 2004 by Simon Cozens.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut
+
 1;
